@@ -9,9 +9,15 @@
 // before initializing the next phase.
 #define REGISTER_BEFORE_STARTING TRUE
 
+// TRUE if the plugin sends notifications
+#define INIT_LIBNOTIFY TRUE
+
 // Setting this to TRUE makes the plugin force GDK_SCALE=1
 #define FORCE_GDK_SCALE TRUE
 
+// This plugin must run under x11/xwayland
+#define FORCE_X11_BACKEND TRUE
+
 #include "csd-color-manager.h"
 
-#include "daemon-skeleton.h"
+#include "daemon-skeleton-gtk.h"
